Stan Math Library: stan::partials_type< stan::math::fvar< T > > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Types | List of all members
stan::partials_type< stan::math::fvar< T > > Struct Template Reference

`#include <partials_type.hpp>`

## Public Types
typedef T | type

## Detailed Description

### template<typename T>
struct stan::partials_type< stan::math::fvar< T > >

Definition at line 10 of file partials_type.hpp.

## Member Typedef Documentation

template<typename T >

typedef T stan::partials_type< stan::math::fvar< T > >::type

Definition at line 11 of file partials_type.hpp.

The documentation for this struct was generated from the following file:

- stan/math/fwd/scal/meta/partials_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.